{ pkgs, ... }:

{
  imports = [ ./desktop-minimal.nix ];

  users.users.nolan = {
    packages = with pkgs; [
      keepassxc
      podman-desktop
      devpod
      gjs
      unstable.fractal
      element-desktop
      discord
      spotify
      thunderbird
      slack
      zoom
      libreoffice
      nil
      nix-index
      nixfmt-rfc-style
      distrobox
      boxbuddy
      flatpak-builder
      appstream
    ];
  };

  programs.firefox.nativeMessagingHosts.gsconnect = true;

  programs.kdeconnect = {
    enable = true;
    package = pkgs.gnomeExtensions.gsconnect;
  };

  home-manager.users.nolan = {
    services = {
      kdeconnect = {
        enable = true;
        indicator = true;
      };
      nextcloud-client.enable = true;
    };
    programs = {
      git = {
        extraConfig = {
          credential.helper = "${pkgs.git.override { withLibsecret = true; }}/bin/git-credential-libsecret";
        };
      };
      jujutsu = {
        enable = true;
        settings = {
          user = {
            name = "Nolan Darilek";
            email = "nolan@thewordnerd.info";
          };
        };
      };
      obs-studio = {
        enable = true;
        plugins = with pkgs.obs-studio-plugins; [
          obs-pipewire-audio-capture
        ];
      };
      vscode = {
        enable = true;
        package = pkgs.unstable.vscode.fhs;
      };
    };
  };
}
